@@ -65,7 +65,10 @@ pub fn reorder_tables(root_ast: &SyntaxNode<Lang>, tables: &Tables) {
             "tool.vendoring",
             // Type checking
             "tool.mypy",
+            "tool.pyrefly",
             "tool.pyright",
+            "tool.ty",
+            "tool.django-stubs",
         ],
     );
 }
