@@ -259,3 +259,29 @@ def test_pyproject_ftm_api_no_change(tmp_path: Path, capsys: pytest.CaptureFixtu
     out, err = capsys.readouterr()
     assert not out
     assert not err
+
+
+def test_no_generate_python_version_classifiers(tmp_path: Path) -> None:
+    txt = """\
+    [project]
+    requires-python = "==3.12"
+    classifiers = [
+      "Programming Language :: Python :: 3 :: Only",
+      "Programming Language :: Python :: 3.12",
+    ]
+    """
+    filename = tmp_path / "pyproject.toml"
+    filename.write_text(dedent(txt))
+    res = run([str(filename), "--no-print-diff", "--no-generate-python-version-classifiers"])
+
+    assert res == 1
+
+    got = filename.read_text()
+
+    expected = """\
+    [project]
+    requires-python = "==3.12"
+    classifiers = [
+    ]
+    """
+    assert got == dedent(expected)
